# Address Contacts
A list of address contacts for the selected person/company saved in the database indicating where they are located. Address contacts will also include data from a person's primary employer. If the person has no primary employer it will include adresses from every one of its employers.

## Columns:
Each column title has three lines on the right if you hover over it. Click on them to show options for that column. The second tab of the options menu will allow you to filter the column, the third to completely hide entire columns. Click on anywhere else on the column to order it, cycling between ascending, descending and no ordering. Hold shift while clicking to order multiple columns with individual weights.

### Location:
The contact's location of use. Can be one of four locations: Work, Private, Home or Other. Work will be selected by default when creating a new contact.

### Street:
The street name and house number of the address contact.

### Street Additional:
Displays optional additional information about the address, e.g. story number.

### Zip:
The address contact's zip code.

### City:
The city of the address.

### State:
The address's state.

### Country:
The country of the address contact.

### Continent:
The address's continent.

## Primary Functionality:
Primary address contacts cannot be deleted unless they are the entry's last address contact. You need to make one of the other contacts their primary address contact before being able to delete that contact.

## Legend:
Click on the legend to filter primary address contacts. When displaying address contacts of a person you can also filter contacts belonging to the person's employer(s) by clicking on the legend "Company Contact".

## Search Field:
Typing in the search field allows to filter the address contacts by their street name, zip code and city name.
